@@ -15,8 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -24,9 +23,11 @@
 #include "help.h"
 
 void 
-show_help (GtkAction *action,
-	   MCData    *mcdata)
+show_help (GSimpleAction *action,
+           GVariant      *parameter,
+           gpointer       user_data)
 {
+	MCData *mcdata = (MCData *) user_data;
     GError *error = NULL;
    
     gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (mcdata->applet)),
